--Creates the TimeDimBuild stored procedure, which adds time records to the TimeDim table in the SBS_OLAP database
USE SBS_OLAP
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[TimeDimBuild]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[TimeDimBuild]
GO

CREATE PROCEDURE dbo.TimeDimBuild 
	@p_start_date DATETIME
	,@p_end_date DATETIME
AS 
  DECLARE @full_date DATETIME
	,@day_of_month INTEGER
	,@day_of_year INTEGER
	,@day_full_name VARCHAR(30)
	,@week_number  INTEGER
	,@week_full_name VARCHAR(30)
	,@month_full_name VARCHAR(10)
	,@month_number INTEGER
	,@calendar_year  INTEGER
	,@quarter INTEGER
WHILE @p_start_date < @p_end_date
   BEGIN 
	SELECT 
        	@full_date = @p_start_date
		,@day_of_month = DATEPART(DD, @p_start_date)
		,@day_of_year = DATEPART(DY, @p_start_date)
		,@day_full_name = UPPER(DATENAME(weekday, @p_start_date))
		,@week_number = DATEPART(WK, @p_start_date)
		,@month_full_name = UPPER(DATENAME(month, @p_start_date))
		,@month_number = DATEPART(M, @p_start_date)
		,@calendar_year = DATEPART(YYYY, @p_start_date)
		,@quarter = DATEPART(QQ, @p_start_date)
	INSERT INTO dbo.TimeDim
		(
		FullDateCode
		,DayOfMonth
		,DayOfYear
		,DayFullName
		,WeekNumber
		,MonthFullName
		,MonthNumber
		,Quarter
		,CalendarYear
		)
	VALUES
		(
		@full_date
		,@day_of_month
		,@day_of_year
		,@day_full_name
		,@week_number
		,@month_full_name
		,@month_number
		,@quarter
		,@calendar_year
		)
    	SELECT @p_start_date = @p_start_date+1
    END       
