/* This script creates two stored procedures. One updates the CustomerDim table using the values 
in the CustomerStage table and one inserts new values into the CustomerDim table using the values
in the CustomerStage table. The value of the CustomerCode column is used to determine which values
are new and which are pre-existing.
*/
USE SBS_OLAP
GO
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.CustomerDimUpdateValues') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.CustomerDimUpdateValues

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.CustomerDimInsertValues') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure dbo.CustomerDimInsertValues
GO
CREATE PROC dbo.CustomerDimUpdateValues @BatchID INT AS
UPDATE dbo.CustomerDim 
  SET 	CustomerCode = cs.CustomerCode
	,CustomerName = cs.CustomerName
	,BillAddress = cs.BillAddress
	,BillCity = cs.BillCity
	,BillRegion = cs.BillRegion
	,BillPostalCode = cs.BillPostalCode
	,BillCountry = cs.BillCountry
	,ShipAddress = cs.ShipAddress
	,ShipCity = cs.ShipCity
	,ShipRegion = cs.ShipRegion
	,ShipPostalCode = cs.ShipPostalCode
	,ShipCountry = cs.ShipCountry
	, BatchID = @BatchID
FROM dbo.CustomerStage as cs
INNER JOIN dbo.CustomerDim as cd
ON cs.CustomerCode = cd.CustomerCode 
WHERE cs.CustomerCode IN (SELECT cd.CustomerCode FROM CustomerDim)
GO

CREATE PROC dbo.CustomerDimInsertValues @BatchID INT AS
INSERT INTO dbo.CustomerDim 
	(CustomerCode, CustomerName, BillAddress, BillCity, BillRegion, BillPostalCode, 
	BillCountry, ShipAddress, ShipCity, ShipRegion, ShipPostalCode, ShipCountry, BatchID)
  SELECT cs.CustomerCode, cs.CustomerName, cs.BillAddress, cs.BillCity
   ,cs.BillRegion, cs.BillPostalCode, cs.BillCountry, cs.ShipAddress
   ,cs.ShipCity, cs.ShipRegion, cs.ShipPostalCode, cs.ShipCountry, @batchID 
FROM dbo.CustomerStage as cs
WHERE cs.CustomerCode NOT IN 
	(SELECT dbo.CustomerDim.CustomerCode FROM dbo.CustomerDim)

